@@ -4,11 +4,11 @@ orddist <- function(x,dim=2)
     size <- (nrow(x)*(nrow(x)-1))/2
     dist <- rep(0.0,size)
     tmp <- .Fortran("orddist",
-        x,
+        as.double(x),
         nrow(x),
         ncol(x),
         as.integer(dim),
-        size,
+        as.integer(size),
         out = dist,
         PACKAGE='labdsv')$out
     attr(tmp,"Size") <- nrow(x)
